#!/bin/sh
#
# Shell script to unpack the MuPAD System.
#
# kg  , 18.05.93 (Last update: 02.02.94 , ok)
# andi, 15.01.96, HP: $* and $# do not work correctly => ARGS and NARGS 
# andi, 10.09.96, NEU: alpha, aminetbsd, i86pc
# andi, 12.12.96, NEU: nextx86, mklinux
#
#set -xv

# ---------------------------- shell variables --------------------------
DIR=`pwd`                     # current working directory

# -------------------------- tools that are needed ----------------------
GUNZIP=gunzip                 # GNU tool to uncompress '.gz' files
GZCAT="$GUNZIP -c"            # GUNZIP, send all output to stdout
TAR=tar                       # UNIX tools to unpack '.tar' archives

# ---------------------------- config variables -------------------------
LINE='############################################################'
VERS='## Installation Script  --  MuPAD 1.3.0   --  12.Dec.1996 ##'

REMOVE=NO                     # Remove automatically tar-archives: YES/NO

# ---------------------------- shell functions --------------------------

#
# echo error message $1 and exit
#
quit() {
   echo "## Error: $1, exiting."
   exit 1
}

#
# read a line from stdin, check if answer is no
#
no() {
  echo "## ""$*""? (y/n) "
  read answer
  test \( "$answer" != "y" \) -a \( "$answer" != "" \)
}

#
# proceed if answer is yes
#
proceed() {
   if no "$*" ; then
      echo "## OK, exiting."
      exit 0
   fi
}

#
# echo error message $1 and usage info, then exit
#
usage() {
   echo ""
   if [ ! "$1" = "" ] ; then
      echo "## Error: $1"
      echo ""
   fi
   echo "usage: $0 [-help|-remove] [ files... ]"
   echo ""
   echo "Unpacks/Installs the MuPAD tar-archives 'files' in the current"
   echo "directory. If no files are given, all MuPAD tar-archives found"
   echo "in the current directory are unpacked/installed."
   echo ""
   exit 1
}

#
# print some information
#
preinfo()
{
   echo $LINE
   echo $VERS
   echo $LINE
   echo ""
   echo "## Please refer to the file README before you install MuPAD!"
   echo ""
   echo "## All MuPAD files will be installed in the directory  MDIR:"
   echo "## MDIR = $DIR"
   echo ""
}

#
# print information about the configuration of MuPAD
#
postinfo() {
echo "## All archives are installed.  Before MuPAD can be started,"
echo "## some environment variables has to be configured. At least"
echo "## the following variables must be set. Refer to the chapter"
echo "## 'How to run MuPAD' of README for detailed information !!!"
echo "##"
echo "## setenv MuPAD_ROOT_PATH $PWD"
echo "## set    path = ( \$MuPAD_ROOT_PATH/share/bin \$path )"
echo "##"
echo "## In order to use  'xmupad' , on some systems you also need"
echo "## to set the environment variable  'SHLIB_PATH' (HP-UX)  or"
echo "## 'LD_LIBRARY_PATH' respectively. Refer to the README. E.g."
echo "##"
echo "## setenv SHLIB_PATH \$MuPAD_ROOT_PATH/hp/xview"
echo ""
}

#
# test if file $1 exists and add it to list
#
checkf() {
   if test -f $1 ; then
      tf="$tf $1"
   else
      usage "file $1 does not exist"
   fi
}

#
# add file $1 to list if it exists
#
addf() {
   if test -f $1 ; then
      tf="$tf $1"
   fi
}

#
# unpack tar-file $1.gz into directory $2
#
unpack() {
   file=$1.gz
   dirc=$2

   echo "## Installing \"${dirc}\" ..."
   if [ -d ${dirc} ] ; then
      proceed "Directory  \"${dirc}\" already exists. Delete it"
      echo "## Removing   \"${dirc}\" ..."
      rm -rf ${dirc} || { quit "cannot remove this directory"; }
   fi
   echo "## Unpacking  \"${file}\" ..."
   
   $GZCAT ${file} | $TAR xpf - || { quit "cannot unpack this archive"; }
   #chmod -R a+rX ${dirc} # if available on your system
   chmod -R a+r ${dirc}
   if [ "$REMOVE" = "YES" ] ; then
      echo "## Removing   \"${file}\" ..."
      rm -f ${file}  || { quit "cannot remove \"${file}\""; }
   fi
   echo "## Ok."
   echo ""
}

# ------------------------- end of shell functions -----------------------

#
# check if option '-help' is set
#
if [ $# -gt 0 ] ; then
   if [ "$1" = "-help" -o "$1" = "-h" ] ; then
      usage ""
   fi
fi

#
# check if tar-archives shall be removed after they are unpacked
#
if [ $# -gt 0 ] ; then
   if [ "$1" = "-remove" ] ; then
      REMOVE=YES
      shift
   fi
fi

#
# save command line arguments before the first shell function
# is called. This is needed on HPs, because '$*' is redefined
# after calling any shell function!
#
NARGS=$#                      # number of parameters given to this script
ARGS=$*                       # parameters given to this script

preinfo
proceed "Proceed"

#
# create list of files to unpack
#
tf=""
if [ $NARGS -eq 0 ] ; then
   #
   # search for MuPAD tar-files
   #
   addf share.tar.gz
   addf share-ext.tar.gz
   addf doc-ext.tar.gz
   addf bin.alpha.tar.gz
   addf bin.aminetbsd.tar.gz
   addf bin.freebsd.tar.gz
   addf bin.hp.tar.gz
   addf bin.i386.tar.gz
   addf bin.i86pc.tar.gz
   addf bin.ibmrs6000.tar.gz
   addf bin.mklinux.tar.gz
   addf bin.nextx86.tar.gz
   addf bin.netbsd.tar.gz
   addf bin.pmax.tar.gz
   addf bin.sgi5.tar.gz
   addf bin.solaris.tar.gz
   addf bin.sun4.tar.gz
   if test -z "$tf" ; then
      usage "no MuPAD tar-archive found in MDIR"
   fi
else
   #
   # test parameters for valid MuPAD tar files
   #
   for f in $ARGS ; do
      case $f in
         share.tar.gz           | \
         share-ext.tar.gz       | \
         doc-ext.tar.gz         | \
	 bin.alpha.tar.gz       | \
	 bin.aminetbsd.tar.gz   | \
         bin.freebsd.tar.gz     | \
	 bin.hp.tar.gz          | \
	 bin.i386.tar.gz        | \
	 bin.i86pc.tar.gz       | \
	 bin.ibmrs6000.tar.gz   | \
         bin.mklinux.tar.gz     | \
         bin.nextx86.tar.gz     | \
         bin.netbsd.tar.gz      | \
	 bin.pmax.tar.gz        | \
	 bin.sgi5.tar.gz        | \
         bin.solaris.tar.gz     | \
         bin.sun4.tar.gz        ) checkf $f 
                                  ;;
         * ) quit "\"$f\" is not a valid MuPAD tar-archive" 
                                  ;;
      esac
   done
fi

#
# unpack files
#
for file in $tf ; do
   case $file in
      share.tar.gz           ) unpack share.tar           share         ;;
      share-ext.tar.gz       ) unpack share-ext.tar       share-ext     ;;
      doc-ext.tar.gz         ) unpack doc-ext.tar         doc-ext       ;;
      bin.alpha.tar.gz       ) unpack bin.alpha.tar       alpha         ;;
      bin.aminetbsd.tar.gz   ) unpack bin.aminetbsd.tar   aminetbsd     ;;
      bin.freebsd.tar.gz     ) unpack bin.freebsd.tar     freebsd       ;;
      bin.hp.tar.gz          ) unpack bin.hp.tar          hp            ;;
      bin.i386.tar.gz        ) unpack bin.i386.tar        i386          ;;
      bin.i86pc.tar.gz       ) unpack bin.i86pc.tar       i86pc         ;;
      bin.ibmrs6000.tar.gz   ) unpack bin.ibmrs6000.tar   ibmrs6000     ;;
      bin.mklinux.tar.gz     ) unpack bin.mklinux.tar     mklinux       ;;
      bin.nextx86.tar.gz     ) unpack bin.nextx86.tar     nextx86       ;;
      bin.netbsd.tar.gz      ) unpack bin.netbsd.tar      netbsd        ;;
      bin.pmax.tar.gz        ) unpack bin.pmax.tar        pmax          ;;
      bin.sgi5.tar.gz        ) unpack bin.sgi5.tar        sgi5          ;;
      bin.solaris.tar.gz     ) unpack bin.solaris.tar     solaris       ;;
      bin.sun4.tar.gz        ) unpack bin.sun4.tar        sun4          ;;
      *                      ) quit "unknown archive \"$file\""   ;;
   esac
done

#
# print information about the configuration of MuPAD
#
postinfo

# end of unpack.sh
